@@ -51,7 +51,7 @@ class BHEMesh():
                 this_point['y'] = meshInput['ADD_POINTS'][i][1]
                 this_point['delta'] = meshInput['ADD_POINTS'][i][2]
                 self.add_points[str(len(self.add_points))] = this_point
-        if mode == 'simple':
+        if mode == 'simple' or mode == 'Simple':
             self.geom['depth'] = max_depth + meshInput['zExt']
             self.geom['dz'] = meshInput['dzLAYER']
             self.geom['dz_ref'] = meshInput['dzREF']
@@ -59,12 +59,14 @@ class BHEMesh():
             self.geom['t_aqf'] = meshInput['t_aqf']
             self.geom['z_aqf'] = meshInput['z_aqf'] + abs(meshInput['inflow_max_z'])
             self.create_layer_structure()
-        elif mode == 'layered':
+        elif mode == 'layered' or mode == 'Layered':
             for i in range(len(meshInput['LAYERING'])):
                 self.layers[str(i)] = {}
                 self.layers[str(i)]['mat_group'] = meshInput['LAYERING'][i][0]
                 self.layers[str(i)]['n_elems'] = meshInput['LAYERING'][i][1]
-                self.layers[str(i)]['elem_thickness'] = meshInput['LAYERING'][i][2]      
+                self.layers[str(i)]['elem_thickness'] = meshInput['LAYERING'][i][2] 
+        else:
+            raise KeyError("'" + mode + "' is not a known mode, please choose 'layered' or 'simple' as mode")     
         self.write_GMSH_mesh()
         self.extrude_mesh()
         self.compute_BHE_elements()
@@ -236,6 +238,14 @@ class BHEMesh():
         gmsh.model.geo.addPlaneSurface([1], 1)
         if 'box' in self.geom:
             for i in self.geom['box']:
+                if self.geom['box'][i]['Origin'][0] <= -0.5*self.geom['width'] or self.geom['box'][i]['Origin'][0] >= 0.5*self.geom['width']:
+                    raise ValueError ("x-coordinate of box " + str(i) + " origin is outside the mesh")
+                elif self.geom['box'][i]['Origin'][0] + self.geom['box'][i]['Width'] >= 0.5*self.geom['width'] or self.geom['box'][i]['Origin'][0] + self.geom['box'][i]['Width'] <= -0.5*self.geom['width']: 
+                    raise ValueError ("x-Widht of box " + str(i) + " is outside the mesh")
+                elif self.geom['box'][i]['Origin'][1] <= 0 or self.geom['box'][i]['Origin'][1] >= self.geom["length"]: 
+                    raise ValueError ("y-Origin of box " + str(i) + " origin is outside the mesh")
+                elif self.geom['box'][i]['Length'] >= self.geom["length"] or self.geom['box'][i]['Origin'][1] + self.geom['box'][i]['Length'] <= 0:
+                    raise ValueError ("y-length of box " + str(i) + " is outside the mesh")
                 lines_list = []
                 point_idx +=1
                 gmsh.model.geo.add_point(self.geom['box'][i]['Origin'][0] + self.geom['box'][i]['Width'], self.geom['box'][i]['Origin'][1], 0, self.geom['box'][i]['Elem_size'], point_idx)
@@ -264,6 +274,10 @@ class BHEMesh():
         alpha = 6.134
         point_list = []
         for i in range(n_BHEs):
+            if self.BHEs[str(i)]['bhe_x'] <= -0.5*self.geom['width'] or self.BHEs[str(i)]['bhe_x'] >= 0.5*self.geom['width']:
+                    raise ValueError ("x-coordinate of bhe " + str(i) + " is outside the mesh")
+            if self.BHEs[str(i)]['bhe_y'] <= 0 or self.BHEs[str(i)]['bhe_y'] >= self.geom['length']:
+                raise ValueError ("y-coordinate of bhe " + str(i) + " is outside the mesh")
             delta = alpha * float(self.BHEs[str(i)]['bhe_radius'])
             point_idx += 1
             gmsh.model.geo.addPoint(self.BHEs[str(i)]['bhe_x'], self.BHEs[str(i)]['bhe_y'], 0, delta, point_idx) 
@@ -289,6 +303,10 @@ class BHEMesh():
         if n_add_points > 0:
             for j in range(n_add_points):
                 point_idx += 1
+                if self.add_points[str(j)]['x'] <= -0.5*self.geom['width'] or self.add_points[str(j)]['x'] >= 0.5*self.geom['width']:
+                    raise ValueError ("x-coordinate of add-point " + str(j) + " is outside the mesh")
+                if self.add_points[str(j)]['y'] <= 0 or self.add_points[str(j)]['y'] >= self.geom['length']:
+                    raise ValueError ("y-coordinate of add-point " + str(j) + " is outside the mesh")
                 gmsh.model.geo.addPoint(self.add_points[str(j)]['x'], self.add_points[str(j)]['y'], 0, self.add_points[str(j)]['delta'], point_idx)
                 point_list.append(point_idx)
         gmsh.model.geo.synchronize()
@@ -535,26 +553,36 @@ class BHEMesh():
         path = []
         normals = {}   
         normals['Top'] =  {'normal' : [0, 0, 1],
-                                'suffix' : "topsf"} 
+                                'suffix' : "topsf"}
+        normals['top'] =  normals['Top']  
         normals['Bottom'] = {'normal' : [0, 0, -1],
                                 'suffix' : "bottomsf"}
+        normals['bottom'] =  normals['Bottom']  
         normals['Back'] = {'normal' : [0, -1, 0],
                                 'suffix' : "backsf"}
+        normals['back'] =  normals['Back']  
         normals['Front'] = {'normal' : [0, 1, 0],
                                 'suffix' : "frontsf"}
+        normals['front'] =  normals['Front']   
         normals['Left'] = {'normal' : [1, 0, 0],
                                 'suffix' : "leftsf"}
+        normals['left'] =  normals['Left']  
         normals['Right'] = {'normal' : [-1, 0, 0],
                                 'suffix' : "rightsf"}
-
+        normals['right'] =  normals['Right']
+        
         normals['Back_inflow'] = normals['Back'].copy()
-        normals['Back_inflow']['suffix'] = "Back_inflowsf"
+        normals['Back_inflow']['suffix'] = "back_inflowsf"
+        normals['back_inflow'] =  normals['Back_inflow']
         normals['Front_inflow'] = normals['Front'].copy()
-        normals['Front_inflow']['suffix'] = "Front_inflowsf"
+        normals['Front_inflow']['suffix'] = "front_inflowsf"
+        normals['front_inflow'] =  normals['Front_inflow']
         normals['Left_inflow'] = normals['Left'].copy()
-        normals['Left_inflow']['suffix'] = "Left_inflowsf"
+        normals['Left_inflow']['suffix'] = "left_inflowsf"
+        normals['left_inflow'] =  normals['Left_inflow']
         normals['Right_inflow'] = normals['Right'].copy()
-        normals['Right_inflow']['suffix'] = "Right_inflowsf"    
+        normals['Right_inflow']['suffix'] = "right_inflowsf"
+        normals['right_inflow'] =  normals['Right_inflow']    
             
         for element in range(len(self.prism_array)):
             if element < self.n_elems_in_plane:
